# Baltes, P.B., Dittmann-Kohli, F., & Kliegl, R. (1986). Reserve capacity  of the elderly
#       in aging-sensitive tests of fluid intelligence : replication and extension
# Psychology and aging, 1 (2), 172-177.

# DOI 10.1037/0882-7974.1.2.172

# R. Kliegl, 2014-01-04

# Variables (scaled T-scores; correct)
#        adi = adept induction
#        afr = adept figural relations
#        thi = thurstone induction
#        cft = culture fair test
#        rav = raven
#        nc  = number comparison
#        ip  = identical pictures
#        kft = vocabulary
#        group: 0 = control, 1 = training
#        _1 = pretest, _3 = posttest 1, _4 = posttest 2, _5 = posttest 3.

library(foreign)
library(stringr)
library(reshape2)
library(plyr)
library(ggplot2)

rm(list=ls())

# Set up
df204w <- read.spss("PA204.sys", to.data.frame=TRUE)[1:33]
names(df204w)[33] <- "group"
df204w$group <- factor(df204w$group, labels=c("control", "training"))
df204w$subj <- factor(1:204)
vars <- names(df204w)[1:32]

# Insert a pattern for latter colsplit
time <- "[1-5]"  # regexp for "1", "2", "3", "4", or "5"
#loc <- as.numeric(str_locate(vars, time)[, 1])  # where?
value <- str_extract(vars, time)    # what?
newvars <- str_c(str_replace(vars, "[1-5]", "_"), value) # equ. to paste()
names(df204w)[1:32] <- newvars

# Split variable into test and time; convert to factors
df204 <- melt(df204w, id=c("group", "subj"))
temp <-  colsplit(df204$variable, "_", c("test", "time"))
df204 <- cbind(df204, temp)[c(1, 2, 5, 6, 4)]
df204$time <- factor(df204$time)
df204$test <- factor(df204$test)
levels(df204$test) <- c("adi", "afr", "cft", "ip", "kft", "nc", "rav", "thi")
df204$test <- factor(df204$test, levels=c("adi", "afr", "thi", "cft", "rav", "nc", "ip", "kft"))

# Table of means, etc.
M_GxTxT <- ddply(df204, .(group, time, test), summarise, 
               N=length(value), M=mean(value), SD=sd(value), SE=SD/sqrt(N) )

# Figure of all means
Fig_0 <- qplot(data=M_GxTxT, x=test, y=M, group=time, shape=time, geom=c("point", "line"), facets=.~group) +
  geom_errorbar(aes(ymin = M - SE, ymax = M + SE), width=0.01) + theme_bw()

# PART II: Analyses of change scores to reproduce Figure 1
c1 <- df204w[,  9:16] - df204w[, 1:8]
c2 <- df204w[, 17:24] - df204w[, 1:8]
c3 <- df204w[, 25:32] - df204w[, 1:8]
df204c <- data.frame( c1, c2, c3, group=df204w$group, subj=df204w$subj)

# Split variable into test and time; convert to factors
df204b <- melt(df204c, id=c("group", "subj"))
temp <-  colsplit(df204b$variable, "_", c("test", "time"))
df204b <- cbind(df204b, temp)[c(1, 2, 5, 6, 4)]
df204b$time <- factor(df204b$time)
df204b$test <- factor(df204b$test)
levels(df204b$test) <- c("adi", "afr", "cft", "ip", "kft", "nc", "rav", "thi")
df204b$test <- factor(df204b$test, levels=c("adi", "afr", "thi", "cft", "rav", "nc", "ip", "kft"))

# Table of means, etc.
M_GxT <- ddply(df204b, .(group, test), summarise, N=length(value), M=mean(value))

# Figure of all means
Fig_1 <- ggplot(M_GxT, aes(x=test, y=M, group=group)) +  geom_line() +
							 scale_y_continuous("Practice Gain", limits=c(0,15), breaks=seq(0,15)) +
               geom_point(aes(shape=group), size=4) +
               scale_shape_manual(values=c(19, 1)) +  theme_bw()
Fig_1
